==> fsds-0.4.10.tar.gz: fsds-0.4.10/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

# requirements = ['scikit-learn','matplotlib','fsds_100719','statsmodels']

# setup_requirements = [ ]

# test_requirements = [ ]
requirements = ['numpy>=1.18.0','missingno', 'pandas>=1.1.3', 'seaborn>=0.11.0', 'matplotlib>=3.2.2', 'scikit-learn>=0.23.1', 
'scipy','IPython','ipywidgets','tzlocal','pyperclip','plotly>=4.0.0','cufflinks>=0.17.0']#'numpy>=1.18','tensorflow>2.1.0','keras'] 
#'pytz','tzlocal','gensim','openpyxl','beautifulsoup4',
setup_requirements = [ 'IPython','missingno',*requirements]

test_requirements = ['IPython' ,'ipywidgets','statsmodels',*requirements]
# test_requirements.extend(requirements)

setup(
    author="James Irving",
    author_email='james.irving.phd@gmail.com',
    python_requires='>=3.7',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Cohort agnostic version of fsds_100719 package",
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=False,
    keywords='fsds',
    name='fsds',
    packages=find_packages(include=['fsds', 'fsds.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/jirvingphd/fsds',
    version='0.4.10',
    zip_safe=False,
)

==> fsds2021-0.1.0.tar.gz: fsds2021-0.1.0/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', ]

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="James Irving",
    author_email='james.irving.phd@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Revamped version of fsds",
    entry_points={
        'console_scripts': [
            'fsds2021=fsds2021.cli:main',
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='fsds2021',
    name='fsds2021',
    packages=find_packages(include=['fsds2021', 'fsds2021.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/jirvingphd/fsds2021',
    version='0.1.0',
    zip_safe=False,
)
